# Software Uninstall Script
# Version 15
# Last updated: 2024-02-20
# Last updated by Felipe Fernandez
# Orginally written by Garth Jones
#
# https://www.RecastSoftware.com
#
# 1-8:		Internal version
# 9:		Orignal Release
# 10:		Jun 18 2018 Fixed bug in calling msi when the uninstall is EXE. Also added hardware inventory scan. 
# 12:		Updated the comments 
<# 13:      February 14 2024 Fixed a bug where it would identify MSIEXEC.exe as the software to uninstall and bypass the MSI uninstall. 
            Also added REGEX to eliminate double quotes in EXE uninstall string.#>
# 14        Fixed some spelling errors 
# 15 		Fix Header.

$appToMatch = '*Adobe Acrobat*'
$e=$MyInvocation.InvocationName
$pshome
$log=$env:temp+'\PSuninstall.log'
$fullinventory = $false
#$fullinventory = $true

function Start-HWInventory
{
    Log-write $log 'Starting HW inventory'
    Log-write $log ' Full Inventory =$fullinventory'
  
    if ($fullinventory -eq $true)
    {
        Log-write $log ' Deleting HW inv calss'
        Get-WmiObject -namespace root\ccm\invagt  -class InventoryActionStatus -filter "InventoryActionID = '{00000000-0000-0000-0000-000000000001}'" | Remove-WmiObject 
    }
    
    Log-write $log ' Starting HW inv. cycle'
  
    Invoke-WMIMethod -Namespace root\ccm -Class SMS_CLIENT -Name TriggerSchedule "{00000000-0000-0000-0000-000000000001}" 
}


function Get-InstalledApps
{
    Log-write $log 'Start Get-InstalledApps'
    if ([IntPtr]::Size -eq 4) {
        $regpath = 'HKLM:\Software\Microsoft\Windows\CurrentVersion\Uninstall\*'
        Log-write $log 'Found x86'
    }
    else {
        $regpath = @(
            'HKLM:\Software\Microsoft\Windows\CurrentVersion\Uninstall\*'
            'HKLM:\Software\Wow6432Node\Microsoft\Windows\CurrentVersion\Uninstall\*'
        )
        Log-write $log 'Found x64'
    }
    Get-ItemProperty $regpath | .{process{if($_.DisplayName -and $_.UninstallString) { $_ } }} | Select DisplayName, Publisher, InstallDate, DisplayVersion, UninstallString, QuietUninstallString |Sort DisplayName
}

Function Log-Write{
  Param ([Parameter(Mandatory=$true)][string]$LogPath, [Parameter(Mandatory=$true)][string]$LineValue) 
    
   Process{ 
     Add-Content -Path $LogPath -Value $LineValue 
   } 
} 


Log-write $log 'Startinging script'

# If running in x86 mode restart in x64 mode.
# Note: This will will closed the SCCM thread and open a new thread. 
if ($PSHome -match 'syswow')
{
    Log-write $log 'Found syswow'
    Log-write $log 'Shell to x64 version'
    start-process "C:\Windows\sysnative\WindowsPowerShell\v1.0\powershell.exe" -arg "-ExecutionPolicy bypass  -file $e" -Wait
    Log-write $log 'Return from x64 version; exiting'
    exit
}



$result = Get-InstalledApps | where {$_.DisplayName -like $appToMatch}
$result 

Log-write $log 'Found these installed apps:'
ForEach ($u in $result) 
{
    $UnInstall = $u.UninstallString 
    $UnInstall = $UnInstall.Trim()

    If ($UnInstall -like 'msiexec.exe*'){
        Log-write $log "uninstall string, containt an MSI"
        $UnInstall = $UnInstall -Replace "msiexec.exe","" -Replace "/I","" -Replace "/X",""
        $UnInstall = $UnInstall.Trim()
        Log-write $log $UnInstall
        Log-write $log 'Start MSIExec'
        start-process "msiexec.exe" -arg "/X $UnInstall /qn /l*v $env:TEMP\$UnInstall.log" -Wait
        Log-write $log 'After MSIExec'
    }
    else
    {
        Log-write $log "Uninstall string, contains an EXE"
        $UnInstall = $UnInstall.Trim()
        $UnInstall = $UnInstall -replace '"', ''
        Log-write $log $UnInstall
        Log-write $log 'Start UninstallEXE'
        start-process -FilePath $UnInstall -argument "/S" -Wait
        Log-write $log 'After UninstallEXE'
    }
} 

Start-HWInventory
